API Reference
=============

This page contains the complete API reference for the Power Switch Pro library.

Main Client
-----------

.. automodule:: power_switch_pro.client
   :members:
   :undoc-members:
   :show-inheritance:

Outlet Management
-----------------

.. automodule:: power_switch_pro.outlets
   :members:
   :undoc-members:
   :show-inheritance:

Authentication & Users
----------------------

.. automodule:: power_switch_pro.auth
   :members:
   :undoc-members:
   :show-inheritance:

Configuration
-------------

.. automodule:: power_switch_pro.config
   :members:
   :undoc-members:
   :show-inheritance:

Power Meters
------------

.. automodule:: power_switch_pro.meters
   :members:
   :undoc-members:
   :show-inheritance:

AutoPing
--------

.. automodule:: power_switch_pro.autoping
   :members:
   :undoc-members:
   :show-inheritance:

Script Execution
----------------

.. automodule:: power_switch_pro.script
   :members:
   :undoc-members:
   :show-inheritance:

Exceptions
----------

.. automodule:: power_switch_pro.exceptions
   :members:
   :undoc-members:
   :show-inheritance:
